function env = adsr(t, ta, td, sl, tr, Fs)
%   ----------------------------------------------------------------
%       
%       Title :     MatLead -SYNTHESIZER-
%       
%       Component : ADSR Envelope Generator
%                   to Amplifier Envelope
%       
%       Version :   1.0.1 Web Edition
%       Date :      2008.5.22
%       Author :    XIAORING <http://mkgweb.undo.jp>
%       Copyright : (c) 2008 XIAORING. All rights reserved.
%       
%   ----------------------------------------------------------------
%       
%       <Arguments>
%       t =     Time Vector (1, n)
%       ta =    Attack Time (sec)
%       td =    Dacay Time (sec)
%       ls =    Sustain Level (ratio(0-1))
%       lr =    Release Time (sec)
%       Fs =    Sampling Frequency (Hz)
%       
%   ----------------------------------------------------------------


%-- Samples --%
    lt = length(t);
    la = floor(ta * Fs);
    ld = floor(td * Fs);
    lr = floor(tr * Fs);
    ls = lt - la - ld - lr;

%-- Emvelope --%
    ea = 0 : 1/(la-1) : 1;
    ed = 1 : -(1-sl)/(ld-1) : sl;
    es = ones(1, ls) * sl;
    er = sl : -1*sl/(lr-1) : 0;
    
%-- Common --%
    env = [ea ed es er];
    env = env(1:lt);
