%   ----------------------------------------------------------------
%
%                       M a t L e a d
%                      - SYNTHESIZER -
%
%       
%       Title :     MatLead -SYNTHESIZER-
%       
%       Component : Root
%       
%       Version :   1.0.1 Web Edition
%       Date :      2008.5.22
%       Author :    XIAORING <http://mkgweb.undo.jp>
%       Copyright : (c) 2008 XIAORING. All rights reserved.
%       
%   ----------------------------------------------------------------
%       
%       <Require Files>
%           synth4.m
%           waveform.m
%           vco2.m
%           vcoPitch.m
%           vcoMix.m
%           vcf.m
%           rg.m
%           lfo.m
%           fmtone3.m
%           vca2.m
%           adsr.m
%           uiVco.m
%           uiLfo.m
%           uiVcf.m
%           uiVca.m
%           uiKeyboard.m
%           uiPreset.m
%           uiScore.m
%           presetRd.m
%           presetWr.m
%           sequencer2.m
%           trackread2.m
%           mkTrk2.m
%           playTrk2,m
%           showAbout.m
%       
%   ----------------------------------------------------------------


%-- Settings --%
    Fs = 44100;
    
    tl = 0.1;   % Note Length (sec)

    % Oscillator
    f = 440;    % Freqency (Hz)
    fp = [0 0 0; 0 0 0];    % Pitch (Vector 2, 3 | col: Octave, Transpose, Tune | row: VCO1, VCO2
    vl = [0.5, 0.5];    % VCO Mix Level (ratio(0-1) | Vector 1, 2 | col: VCO1, VCO2)
    
    % LFO
    fw = 0.05;  % LFO Amount (times)
    fv = 10;    % LFO Rate (Hz)
    fa = [0.50 0.50];  % LFO Attack (sec | Vector 1, 2 | col: Amount, Speed) 
    fi = [0 0 0]; % LFO IN/OUT
    
    % Waveform
    wf = [2 2]; % Waveform (number: 1-5)
    cf = 6;     % Cutoff Freqency (number: 1-6)
    n = floor(2^cf);    % Number of Harmonics (number)
  
    % Amp Envelope
    ta = 0.00;  % A Time (sec)
    td = 0.00;  % D Time (sec)
    sl = 1.00;  % S Level (ratio(0-1))
    tr = 0.00;  % R Time (sec)
    
    % Filter Envelope
    fei = [0 0 1]; % Filter Envelope IN/OUT
    feInv = [0 0 0]; % Inverse IN/OUT
    tah = 0.00; % A Time (sec)
    tdh = 0.00; % D Time (sec)
    slh = 1.00; % S Level (ratio(0-1))
    trh = 0.00; % R Time (sec)
    
    % Resonator
    rr = 1.0;   % Resonator Character
    rc = 1;     % Center Harmonics of Resonator
    rbw = 0;    % Band Width of Resonator
    
    % Color
    clrBody = [0.65 0.2 0.2];
    % clrBody = [0.2 0.2 0.2];
    clrPanel = [0.35 0.35 0.4];
    clrDiv1 = [0.4 0.5 0.4];
    clrDiv2 = [0.5 0.4 0.4];
    clrDiv3 = [0.4 0.4 0.55];
    clrLabel = [0.9 0.9 0.9];
    clrTextFore = [0.0 0.4 0.1];
    clrTextBack = [0.2 0.9 0.0];
    clrSl = [0.2 0.2 0.3];
    clrBtn1 = [0.85 0.9 0.8];
    clrBtn2 = [0.9 0.85 0.8];
    clrBtn3 = [0.85 0.85 0.9];
    clrBtnStr = [0.2 0.2 0.2];

    
%-- Figure --%
    hf = figure( ...
        'position', [160 150 780 480], ...
        'color', clrBody, ...
        'name', 'MatLead' ...
    );

    
uiVco;
uiLfo;
uiVcf;
uiVca;    
uiKeyboard;
uiScore;
uiPreset;

%-- About --%
    % Callback
    cAbout = 'showAbout;';

    % UI
    hAbout = uicontrol( ...
        'style', 'pushbutton', ...
        'units', 'pixels', ...
        'position', [745 440 20 20], ...
        'back', clrBtn3, ...
        'fore', clrBtnStr, ...
        'String', '?', ...
        'callback', cAbout ...
    );

%-- Logo --%
    hpLogo = uipanel(...
        'units', 'pixels', ...
        'position', [470 190 280 40], ...
        'back', clrBody, ...
        'fore', clrLabel ...
    );
    hLogo1 = uicontrol( ...
        'style', 'text', ...
        'parent', hpLogo, ...
        'units', 'pixels', ...
        'position', [5 5 140 30], ...
        'back', clrBody, ...
        'fore', clrLabel, ...
        'FontName', 'Tahoma', ...
        'FontUnits', 'pixels', ...
        'FontSize', 30, ...
        'FontAngle', 'italic', ...
        'string', 'MatLead' ...
    );
    hLogo2 = uicontrol( ...
        'style', 'text', ...
        'parent', hpLogo, ...
        'units', 'pixels', ...
        'position', [145 5 130 15], ...
        'back', clrBody, ...
        'fore', clrLabel, ...
        'FontName', 'Tahoma', ...
        'FontUnits', 'pixels', ...
        'FontSize', 15, ...
        'FontAngle', 'italic', ...
        'string', '- SYNTHESIZER -' ...
    );
