function y = synth4(tl, f, fp, vl, fw, fv, fa, fi, n, wf, ta, td, sl, tr, fei, feInv, tah, tdh, slh, trh, rr, rc, rbw, Fs)
%   ----------------------------------------------------------------
%       
%       Title :     MatLead -SYNTHESIZER-
%       
%       Component : Synthesizer
%                   w/ LFO, VCO, VCF, VCA, RG
%       
%       Version :   1.0.1 Web Edition
%       Date :      2008.5.22
%       Author :    XIAORING <http://mkgweb.undo.jp>
%       Copyright : (c) 2008 XIAORING. All rights reserved.
%       
%   ----------------------------------------------------------------
%
%       <Arguments>
%       tl =    Time Length (sec)
%       
%       f =     Frequency (Hz)
%       fp =    Pitch (Vector 2, 3 | col: Octave, Transpose, Tune | row: VCO1, VCO2
%       vl =    VCO Mix Level (ratio(0-1) | Vector 1, 2 | col: VCO1, VCO2)
%       
%       fw =    LFO Amount (times)
%       fv =    LFO Rate (Hz)
%       fa =    LFO Attack (sec | Vector 1, 2 | col: Amount, Speed)
%       fi =    LFO In/Out (Bool | Vector: VCO1, VCO2, VCA)
%                   0 = Out (Switch Off)
%                   1 = In (Switch On)
%       
%       n =     Harmonics Number (number)
%       wf =    Waveform (number (1-5) | Vector 1, 2 | col: VCO1, VCO2)
%                   1 = Sine
%                   2 = Saw
%                   3 = Square
%                   4 = Triangle
%                   5 = Ramp
%       
%       ta =    Attack Time (sec)
%       td =    Dacay Time (sec)
%       sl =    Sustain Level (ratio(0-1))
%       lr =    Release Time (sec)
%       
%       fei =   Filter Envelope In/Out (Bool | Vector: VCO1, VCO2, VCF)
%                   0 = Out (Switch Off)
%                   1 = In (Switch On)
%       feInv = Filter Envelope Inverse In/Out (Bool | Vector: VCO1, VCO2, VCF)
%                   0 = Out (Switch Off)
%                   1 = In (Switch On)
%       tah =   Attack Time of Filter Env (sec)
%       tdh =   Dacay Time of Filter Env (sec)
%       slh =   Sustain Level of Filter Env (ratio(0-1))
%       lrh =   Release Time of Filter Env (sec)
%       
%       rr =    Resonator Character (ratio)
%       rc =    Center Harmonics of Resonator (number)
%       rbw =   Band Width of Resonator (number)
%       
%       Fs =    Sampling Rate (Hz)
%
%       <Required Files>
%           waveform.m
%           vco2.m
%           vcoPitch.m
%           vcoMix.m
%           vcf.m
%           rg.m
%           lfo2s.m
%           fmtone3.m
%           vca3.m
%           adsr.m
%       
%   ----------------------------------------------------------------


%-- Initial --%
    d = 1 / Fs;
    t = 0 : d : tl;
    
    ar = rg(n, rr, rc, rbw);

%-- Oscillator --%
    % Super Detune Mode
    if fp(1, 1) == 100 && fp(1, 2) == -1200 && fp(2, 1) == -100 && fp(2, 2) == 1200;
        y11 = vco2(t, tl, f*vcoPitch([0 0 -20]), fp(1, 1:3), fw, fv, fa, fi(1), n, wf(1), [fei(1) fei(3)], [feInv(1) feInv(3)], tah, tdh, slh, trh, ar, Fs);
        y21 = vco2(t, tl, f*vcoPitch([0 0 -20]), fp(2, 1:3), fw, fv, fa, fi(2), n, wf(2), [fei(2) fei(3)], [feInv(2) feInv(3)], tah, tdh, slh, trh, ar, Fs);
        y12 = vco2(t, tl, f, fp(1, 1:3), fw, fv, fa, fi(1), n, wf(1), [fei(1) fei(3)], [feInv(1) feInv(3)], tah, tdh, slh, trh, ar, Fs);
        y22 = vco2(t, tl, f, fp(2, 1:3), fw, fv, fa, fi(2), n, wf(2), [fei(2) fei(3)], [feInv(2) feInv(3)], tah, tdh, slh, trh, ar, Fs);
        y13 = vco2(t, tl, f*vcoPitch([0 0 20]), fp(1, 1:3), fw, fv, fa, fi(1), n, wf(1), [fei(1) fei(3)], [feInv(1) feInv(3)], tah, tdh, slh, trh, ar, Fs);
        y23 = vco2(t, tl, f*vcoPitch([0 0 20]), fp(2, 1:3), fw, fv, fa, fi(2), n, wf(2), [fei(2) fei(3)], [feInv(2) feInv(3)], tah, tdh, slh, trh, ar, Fs);
        y1 = vcoMix(vcoMix(y11, y12, [0.5 0.5]), y13, [0.5 0.5]);
        y2 = vcoMix(vcoMix(y21, y22, [0.5 0.5]), y23, [0.5 0.5]);
    else
        y1 = vco2(t, tl, f, fp(1, 1:3), fw, fv, fa, fi(1), n, wf(1), [fei(1) fei(3)], [feInv(1) feInv(3)], tah, tdh, slh, trh, ar, Fs);
        y2 = vco2(t, tl, f, fp(2, 1:3), fw, fv, fa, fi(2), n, wf(2), [fei(2) fei(3)], [feInv(2) feInv(3)], tah, tdh, slh, trh, ar, Fs);
    end
    
%-- VCO Mixer --%
    y = vcoMix(y1, y2, vl);
    
%-- Amplifier --%
    y = vca3(y, t, ta, td, sl, tr, fw, fv, fa, fi(3), Fs);

%-- Make Margin --%
    % y = [y zeros(1, 0.1*Fs)];

