function y = vca3(y, t, ta, td, sl, tr, fw, fv, fa, fi, Fs)
%   ----------------------------------------------------------------
%       
%       Title :     MatLead -SYNTHESIZER-
%       
%       Component : Voltage Contoled Amplifier
%                   to Amplifier Envelope
%       
%       Version :   1.0.1 Web Edition
%       Date :      2008.5.22
%       Author :    XIAORING <http://mkgweb.undo.jp>
%       Copyright : (c) 2008 XIAORING. All rights reserved.
%       
%   ----------------------------------------------------------------
%
%       <Arguments>
%       y =     Sound Vector (1, n)
%       t =     Time Vector (1, n)
%       ta =    Attack Time (sec)
%       td =    Dacay Time (sec)
%       ls =    Sustain Level (ratio(0-1))
%       lr =    Release Time (sec)
%       fw =    LFO Amount (times)
%       fv =    LFO Rate (Hz)
%       fa =    LFO Attack (sec)
%       fi =    LFO In/Out
%                   0 = Out (Switch Off)
%                   1 = In (Switch On)
%       Fs =    Sampling Frequency (Hz)
%       
%       <Required File>
%           adsr,m
%       
%   ----------------------------------------------------------------

%-- ADSR --%
    env = adsr(t, ta, td, sl, tr, Fs);

    yL = length(y);
    ampenv = ones(1, yL);

    atime = 0.01;
    rtime = 0.02;

    aL = floor(atime * Fs);
    rL = floor(rtime * Fs);

    attack = 0 : 1/(aL-1) : 1;
    release = 1 : -1/(rL-1) : 0;

    ampenv(1 : aL) = attack;
    ampenv(yL-rL+1 : yL) = release;
    
%-- LFO --%
    if fi >= 1;
        fenv = adsr(t, ta, 0, 1, 0, Fs);
        finst = 1 - (fw * sin(2 * pi * fv * t) .* fenv);
        y = y .* env .* finst .* ampenv;
    else
        y = y .* env .* ampenv;
    end


%-- Limiting --%
    y = y / abs( max(y) );

