function envh = vcf(i, n, tl, ta, td, sl, tr, Fs)
%   ----------------------------------------------------------------
%       
%       Title :     MatLead -SYNTHESIZER-
%       
%       Component : Voltage Contoled Filter
%                   to Harmonics Envelope
%       
%       Version :   1.0.1 Web Edition
%       Date :      2008.5.22
%       Author :    XIAORING <http://mkgweb.undo.jp>
%       Copyright : (c) 2008 XIAORING. All rights reserved.
%       
%   ----------------------------------------------------------------
%
%       <Arguments>
%       i =     Harmonics ID (number)
%       n =     Number of Harmonics (number)
%       tl =    Length (sec)
%       ta =    Attack Time (sec)
%       td =    Dacay Time (sec)
%       ls =    Sustain Level (ratio(0-1))
%       lr =    Release Time (sec)
%       Fs =    Sampling Frequency (Hz)
%       
%   ----------------------------------------------------------------


ni = i / n;

%-- Time --%
    da = ta * ni;

    if ni > sl
        ds = (ta + td) - (ni-sl)/(1-sl) * td - da;
    else
        ds = tl - (ni/sl) * tr - da;
    end

    dr = 0.02;

%-- Samples --%
    lt = floor(tl*Fs)+1;
    la = round(da*Fs);
    ls = round(ds*Fs);
    lr = round(dr*Fs);
    le = lt - la - ls - lr;

%-- Envelope --%
    ea = 0:1/(la-1):1;
    es = ones(1,ls);
    er = 1:-1/(lr-1):0;
    ee = zeros(1, le);

%-- Common --%
    envh = [ea es er ee];
    envh = envh(1:lt);
