function y = vco2(t, tl, f, fp, fw, fv, fa, fi, n, wf, fei, feInv, tah, tdh, slh, trh, ar, Fs)
%   ----------------------------------------------------------------
%       
%       Title :     MatLead -SYNTHESIZER-
%       
%       Component : Voltage Controlled Oscillator
%       
%       Version :   1.0.1 Web Edition
%       Date :      2008.5.22
%       Author :    XIAORING <http://mkgweb.undo.jp>
%       Copyright : (c) 2008 XIAORING. All rights reserved.
%       
%   ----------------------------------------------------------------
%
%       <Arguments>
%       t =     Time Vector (1, n)
%       tl =    Time length (sec)
%       
%       f =     Frequency (Hz)
%       fp =    Pitch (Vector 1, 3 | col: Octave, Transpose, Tune)
%       
%       fw =    LFO Amount (times)
%       fv =    LFO Rate (Hz)
%       fa =    LFO Attack (sec | Vector 1, 2 | col: Amount, Speed)
%       fi =    LFO In/Out
%                   0 = Out (Switch Off)
%                   1 = In (Switch On)
%       
%       n =     Harmonics Number (number)
%       wf =    Waveform
%                   1 = Sine
%                   2 = Saw
%                   3 = Square
%                   4 = Triangle
%                   5 = Ramp
%       
%       fei =   Filter Envelope In/Out (Bool | Vector: VCO, VCF)
%                   0 = Out (Switch Off)
%                   1 = In (Switch On)
%       feInv = Filter Envelope Inverse In/Out (Bool | Vector: VCO, VCF)
%                   0 = Out (Switch Off)
%                   1 = In (Switch On)
%       tah =   Attack Time of Filter Env (sec)
%       tdh =   Dacay Time of Filter Env (sec)
%       slh =   Sustain Level of Filter Env (ratio(0-1))
%       lrh =   Release Time of Filter Env (sec)
%       
%       ar =    Resonance Responce Vector (1, n)
%       
%       Fs =    Sampling Rate (Hz)
%
%       <Required Files>
%           vcoPitch.m
%           vcf.m
%           lfo2.m
%           fmtone3.m
%       
%   ----------------------------------------------------------------


    d = 1 / Fs;
    a = waveform(n, wf);
    y = zeros(size(t));
    if feInv(1) >= 1 
        feiRate = -0.9;
    else
        feiRate = 10;
    end

%-- Tone Generation by Harmonics --%
    for i = 1 : n;
        
        % Filter
        if fei(2) < 1;
            envh = ones(1, length(t));
        else
            envh = vcf(i, n, tl, tah, tdh, slh, trh, Fs);
        end

        % Pitch
        if fi < 1;
            finst = ones(1, length(t)) .* (1 + adsr(t, tah, tdh, slh, trh, Fs) * fei(1) * feiRate) * f * i * vcoPitch(fp);
        else
            finst = lfo2(t, f*i, fw, fv, fa, Fs) .* (1 + adsr(t, tah, tdh, slh, trh, Fs) * fei(1) * feiRate) * vcoPitch(fp);
        end
        
        % Oscillator
        harm = envh .* fmtone3(t, d, finst, a(i), ar(i));
        y = y + harm;
    end

